@@ -6,10 +6,9 @@ use File::Spec;
 use FindBin;
 use LWP::Simple;
 use URI;
-#use URI::Escape qw(uri_unescape);
 use Date::Format;
 
-$CGI::SSI::VERSION = '0.51';
+$CGI::SSI::VERSION = '0.80';
 
 my $debug = 0;
 
@@ -77,20 +76,27 @@ sub TIEHANDLE {
 }
 
 sub PRINT {
-    my($self,@shtml) = @_;
-    print {$self->{'_handle'}} map { $self->process($_) } @shtml;
+    my $self = shift;
+    print {$self->{'_handle'}} map { $self->process($_) } @_;
+}
+
+sub PRINTF {
+    my $self = shift;
+    my $fmt  = shift;
+    printf {$self->{'_handle'}} $fmt, map { $self->process($_) } @_;
 }
 
 sub process {
     my($self,@shtml) = @_;
     my $processed = '';
     @shtml = split(/(<!--#.+?-->)/,join '',@shtml);
+    local($HTML::SimpleParse::FIX_CASE) = 0; # prevent var => value from becoming VAR => value
     for my $token (@shtml) {
 #	next unless(defined $token and length $token);
         if($token =~ /^<!--#(.+?)\s*-->$/) {
-	    $processed .= $self->_process_ssi_text($self->_interp_vars($1));
+            $processed .= $self->_process_ssi_text($self->_interp_vars($1));
 	} else {
-	    next if $self->_suspended;
+            next if $self->_suspended;
 	    $processed .= $token;
 	}
     }
